==> eventum-3.8.2.tar.xz: eventum-3.8.2/localization/LINGUAS.php <==
<?php
$avail_langs = array(
	// TRANSLATORS: Translation of Arabic language in preferences dropdown
	'ar' => _('Arabic'),
	// TRANSLATORS: Translation of Breton language in preferences dropdown
	'br' => _('Breton'),
	// TRANSLATORS: Translation of Catalan language in preferences dropdown
	'ca' => _('Catalan'),
	// TRANSLATORS: Translation of Czech language in preferences dropdown
	'cs' => _('Czech'),
	// TRANSLATORS: Translation of Danish language in preferences dropdown
	'da' => _('Danish'),
	// TRANSLATORS: Translation of German language in preferences dropdown
	'de' => _('German'),
	// TRANSLATORS: Translation of English (Australia) language in preferences dropdown
	'en_AU' => _('English (Australia)'),
	// TRANSLATORS: Translation of English (Canada) language in preferences dropdown
	'en_CA' => _('English (Canada)'),
	// TRANSLATORS: Translation of English (United Kingdom) language in preferences dropdown
	'en_GB' => _('English (United Kingdom)'),
	// TRANSLATORS: Translation of Esperanto language in preferences dropdown
	'eo' => _('Esperanto'),
	// TRANSLATORS: Translation of Spanish language in preferences dropdown
	'es' => _('Spanish'),
	// TRANSLATORS: Translation of Estonian language in preferences dropdown
	'et' => _('Estonian'),
	// TRANSLATORS: Translation of Finnish language in preferences dropdown
	'fi' => _('Finnish'),
	// TRANSLATORS: Translation of Faroese language in preferences dropdown
	'fo' => _('Faroese'),
	// TRANSLATORS: Translation of French language in preferences dropdown
	'fr' => _('French'),
	// TRANSLATORS: Translation of Hebrew language in preferences dropdown
	'he' => _('Hebrew'),
	// TRANSLATORS: Translation of Haitian; Haitian Creole language in preferences dropdown
	'ht' => _('Haitian; Haitian Creole'),
	// TRANSLATORS: Translation of Hungarian language in preferences dropdown
	'hu' => _('Hungarian'),
	// TRANSLATORS: Translation of Indonesian language in preferences dropdown
	'id' => _('Indonesian'),
	// TRANSLATORS: Translation of Italian language in preferences dropdown
	'it' => _('Italian'),
	// TRANSLATORS: Translation of Japanese language in preferences dropdown
	'ja' => _('Japanese'),
	// TRANSLATORS: Translation of Korean language in preferences dropdown
	'ko' => _('Korean'),
	// TRANSLATORS: Translation of Lithuanian language in preferences dropdown
	'lt' => _('Lithuanian'),
	// TRANSLATORS: Translation of Latvian language in preferences dropdown
	'lv' => _('Latvian'),
	// TRANSLATORS: Translation of Dutch language in preferences dropdown
	'nl' => _('Dutch'),
	// TRANSLATORS: Translation of Occitan (post 1500) language in preferences dropdown
	'oc' => _('Occitan (post 1500)'),
	// TRANSLATORS: Translation of Polish language in preferences dropdown
	'pl' => _('Polish'),
	// TRANSLATORS: Translation of Portuguese language in preferences dropdown
	'pt' => _('Portuguese'),
	// TRANSLATORS: Translation of Brasiliant Portugese language in preferences dropdown
	'pt_BR' => _('Brasiliant Portugese'),
	// TRANSLATORS: Translation of Russian language in preferences dropdown
	'ru' => _('Russian'),
	// TRANSLATORS: Translation of Sinhalese language in preferences dropdown
	'si' => _('Sinhalese'),
	// TRANSLATORS: Translation of Swedish language in preferences dropdown
	'sv' => _('Swedish'),
	// TRANSLATORS: Translation of Tamil language in preferences dropdown
	'ta' => _('Tamil'),
	// TRANSLATORS: Translation of Thai language in preferences dropdown
	'th' => _('Thai'),
	// TRANSLATORS: Translation of Turkish language in preferences dropdown
	'tr' => _('Turkish'),
	// TRANSLATORS: Translation of Ukrainian language in preferences dropdown
	'uk' => _('Ukrainian'),
	// TRANSLATORS: Translation of Urdu language in preferences dropdown
	'ur' => _('Urdu'),
	// TRANSLATORS: Translation of Vietnamese language in preferences dropdown
	'vi' => _('Vietnamese'),
	// TRANSLATORS: Translation of Chinese (Simplified) language in preferences dropdown
	'zh_CN' => _('Chinese (Simplified)'),
);

==> eventum-3.10.0.tar.xz: eventum-3.10.0/localization/LINGUAS.php <==
<?php
$avail_langs = array(
	// TRANSLATORS: Translation of Arabic language in preferences dropdown
	'ar' => _('Arabic'),
	// TRANSLATORS: Translation of Breton language in preferences dropdown
	'br' => _('Breton'),
	// TRANSLATORS: Translation of Catalan language in preferences dropdown
	'ca' => _('Catalan'),
	// TRANSLATORS: Translation of Czech language in preferences dropdown
	'cs' => _('Czech'),
	// TRANSLATORS: Translation of Danish language in preferences dropdown
	'da' => _('Danish'),
	// TRANSLATORS: Translation of German language in preferences dropdown
	'de' => _('German'),
	// TRANSLATORS: Translation of English (Australia) language in preferences dropdown
	'en_AU' => _('English (Australia)'),
	// TRANSLATORS: Translation of English (Canada) language in preferences dropdown
	'en_CA' => _('English (Canada)'),
	// TRANSLATORS: Translation of English (United Kingdom) language in preferences dropdown
	'en_GB' => _('English (United Kingdom)'),
	// TRANSLATORS: Translation of Esperanto language in preferences dropdown
	'eo' => _('Esperanto'),
	// TRANSLATORS: Translation of Spanish language in preferences dropdown
	'es' => _('Spanish'),
	// TRANSLATORS: Translation of Estonian language in preferences dropdown
	'et' => _('Estonian'),
	// TRANSLATORS: Translation of Finnish language in preferences dropdown
	'fi' => _('Finnish'),
	// TRANSLATORS: Translation of Faroese language in preferences dropdown
	'fo' => _('Faroese'),
	// TRANSLATORS: Translation of French language in preferences dropdown
	'fr' => _('French'),
	// TRANSLATORS: Translation of Hebrew language in preferences dropdown
	'he' => _('Hebrew'),
	// TRANSLATORS: Translation of Haitian; Haitian Creole language in preferences dropdown
	'ht' => _('Haitian; Haitian Creole'),
	// TRANSLATORS: Translation of Hungarian language in preferences dropdown
	'hu' => _('Hungarian'),
	// TRANSLATORS: Translation of Indonesian language in preferences dropdown
	'id' => _('Indonesian'),
	// TRANSLATORS: Translation of Italian language in preferences dropdown
	'it' => _('Italian'),
	// TRANSLATORS: Translation of Japanese language in preferences dropdown
	'ja' => _('Japanese'),
	// TRANSLATORS: Translation of Korean language in preferences dropdown
	'ko' => _('Korean'),
	// TRANSLATORS: Translation of Lithuanian language in preferences dropdown
	'lt' => _('Lithuanian'),
	// TRANSLATORS: Translation of Latvian language in preferences dropdown
	'lv' => _('Latvian'),
	// TRANSLATORS: Translation of Dutch language in preferences dropdown
	'nl' => _('Dutch'),
	// TRANSLATORS: Translation of Occitan (post 1500) language in preferences dropdown
	'oc' => _('Occitan (post 1500)'),
	// TRANSLATORS: Translation of Polish language in preferences dropdown
	'pl' => _('Polish'),
	// TRANSLATORS: Translation of Portuguese language in preferences dropdown
	'pt' => _('Portuguese'),
	// TRANSLATORS: Translation of Brazilian Portuguese language in preferences dropdown
	'pt_BR' => _('Brazilian Portuguese'),
	// TRANSLATORS: Translation of Russian language in preferences dropdown
	'ru' => _('Russian'),
	// TRANSLATORS: Translation of Sinhalese language in preferences dropdown
	'si' => _('Sinhalese'),
	// TRANSLATORS: Translation of Swedish language in preferences dropdown
	'sv' => _('Swedish'),
	// TRANSLATORS: Translation of Tamil language in preferences dropdown
	'ta' => _('Tamil'),
	// TRANSLATORS: Translation of Thai language in preferences dropdown
	'th' => _('Thai'),
	// TRANSLATORS: Translation of Turkish language in preferences dropdown
	'tr' => _('Turkish'),
	// TRANSLATORS: Translation of Ukrainian language in preferences dropdown
	'uk' => _('Ukrainian'),
	// TRANSLATORS: Translation of Urdu language in preferences dropdown
	'ur' => _('Urdu'),
	// TRANSLATORS: Translation of Vietnamese language in preferences dropdown
	'vi' => _('Vietnamese'),
	// TRANSLATORS: Translation of Chinese (Simplified) language in preferences dropdown
	'zh_CN' => _('Chinese (Simplified)'),
);
